==> classes_aux-0.1.4.tar.gz: classes_aux-0.1.4/README.md <==
![Ver/TestedPython](https://img.shields.io/pypi/pyversions/classes_aux)
![Ver/Os](https://img.shields.io/badge/os_development-Windows-blue)  
![repo/Created](https://img.shields.io/github/created-at/centroid457/classes_aux)
![Commit/Last](https://img.shields.io/github/last-commit/centroid457/classes_aux)
![Tests/GitHubWorkflowStatus](https://github.com/centroid457/classes_aux/actions/workflows/test_linux.yml/badge.svg)
![Tests/GitHubWorkflowStatus](https://github.com/centroid457/classes_aux/actions/workflows/test_windows.yml/badge.svg)  
![repo/Size](https://img.shields.io/github/repo-size/centroid457/classes_aux)
![Commit/Count/t](https://img.shields.io/github/commit-activity/t/centroid457/classes_aux)
![Commit/Count/y](https://img.shields.io/github/commit-activity/y/centroid457/classes_aux)
![Commit/Count/m](https://img.shields.io/github/commit-activity/m/centroid457/classes_aux)

# classes_aux (current v0.1.4/![Ver/Pypi Latest](https://img.shields.io/pypi/v/classes_aux?label=pypi%20latest))

## DESCRIPTION_SHORT
attempt to keep all useful classes and classesTemplates in one place

## DESCRIPTION_LONG
designed for ...


## Features
1. cmp  
2. getattr prefix  
3. getattr echo  
4. middle group  
5. NumberArithm  


********************************************************************************
## License
See the [LICENSE](LICENSE) file for license rights and limitations (MIT).


## Release history
See the [HISTORY.md](HISTORY.md) file for release history.


## Installation
```commandline
pip install classes-aux
```


## Import
```python
from classes_aux import *
```


********************************************************************************
## USAGE EXAMPLES
See tests and sourcecode for other examples.

------------------------------
### 1. example1.py
```python

```

********************************************************************************

==> classes_aux-0.1.5.tar.gz: classes_aux-0.1.5/README.md <==
![Ver/TestedPython](https://img.shields.io/pypi/pyversions/classes_aux)
![Ver/Os](https://img.shields.io/badge/os_development-Windows-blue)  
![repo/Created](https://img.shields.io/github/created-at/centroid457/classes_aux)
![Commit/Last](https://img.shields.io/github/last-commit/centroid457/classes_aux)
![Tests/GitHubWorkflowStatus](https://github.com/centroid457/classes_aux/actions/workflows/test_linux.yml/badge.svg)
![Tests/GitHubWorkflowStatus](https://github.com/centroid457/classes_aux/actions/workflows/test_windows.yml/badge.svg)  
![repo/Size](https://img.shields.io/github/repo-size/centroid457/classes_aux)
![Commit/Count/t](https://img.shields.io/github/commit-activity/t/centroid457/classes_aux)
![Commit/Count/y](https://img.shields.io/github/commit-activity/y/centroid457/classes_aux)
![Commit/Count/m](https://img.shields.io/github/commit-activity/m/centroid457/classes_aux)

# classes_aux (current v0.1.5/![Ver/Pypi Latest](https://img.shields.io/pypi/v/classes_aux?label=pypi%20latest))

## DESCRIPTION_SHORT
attempt to keep all useful classes and classesTemplates in one place

## DESCRIPTION_LONG
designed for ...


## Features
1. cmp  
2. getattr prefix  
3. getattr echo  
4. middle group  
5. NumberArithm  


********************************************************************************
## License
See the [LICENSE](LICENSE) file for license rights and limitations (MIT).


## Release history
See the [HISTORY.md](HISTORY.md) file for release history.


## Installation
```commandline
pip install classes-aux
```


## Import
```python
from classes_aux import *
```


********************************************************************************
## USAGE EXAMPLES
See tests, sourcecode and docstrings for other examples.  

------------------------------
### 1. example1.py
```python

```

********************************************************************************
